@@ -6,4 +6,5 @@ __all__ = ["ACSF", "behlerparrinello",
            "SOAP",
            "SO3",
            "SO4",
-           "wACSF", "cutoff"]
+           "wACSF",
+           "cutoff"]
